<?php

/**
 * @file
 * Contains Drupal\nys_unav\Form\NysUNavForm
 */

namespace Drupal\nys_unav\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\system\Entity\Menu;

class NysUNavForm extends ConfigFormBase {

    /**
     * {@inheritdoc}.
     */
    public function getFormId() {
        return 'nys_unav_form';
    }

    /**
     * {@inheritdoc}.
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
        // Form constructor
        $form = parent::buildForm($form, $form_state);
        // Default settings
        $config = $this->config('nys_unav.settings');
        
        $form['nys_unav_language_access_fieldset'] = $this->_nys_unav_language_access_fieldset();
        $form['nys_unav_language_access_fieldset']['nys_unav_language_access_header'] = $this->_nys_unav_language_access_header();
        $form['nys_unav_language_access_fieldset']['nys_unav_language_access_footer'] = $this->_nys_unav_language_access_footer();


        return $form;
    }

    /**
     * {@inheritdoc}.
     */
    public function validateForm(array &$form, FormStateInterface $form_state)
    {

    }

    /**
     * {@inheritdoc}.
     */
    public function submitForm(array &$form, FormStateInterface $form_state)
    {
        $config = \Drupal::configFactory()->getEditable('nys_unav.settings');
        $config->set('nys_unav.nys_unav_language_access_header', $form_state->getValue('nys_unav_language_access_header'));
        $config->set('nys_unav.nys_unav_language_access_footer', $form_state->getValue('nys_unav_language_access_footer'));
        $config->save();

        // CLEAR CACHE
        drupal_flush_all_caches();
        
        return parent::submitForm($form, $form_state);
    }

    /**
     * {@inheritdoc}.
     */
    protected function getEditableConfigNames()
    {
        return [
            'nys_unav.settings',
        ];
    }

    /**
     * NYS Universal Navigation language access fieldset field.
     *
     * @return array
     *   Form API element for field.
     */
    public function _nys_unav_language_access_fieldset() {
        return array(
          '#type' => 'fieldset',
          '#title' => t('NYS Language Access Options'),
          '#collapsible' => FALSE,
          '#collapsed' => FALSE,
        );
    }
  
      /**
       * NYS Universal Navigation language access field.
       *
       * @return array
       *   Form API element for field.
       */
    public function _nys_unav_language_access_header() {
    $config = $this->config('nys_unav.settings');
    return array(
        '#type' => 'checkbox',
        '#title' => t('Enable the Language Access Header'),
        '#default_value' => $config->get('nys_unav.nys_unav_language_access_header'),
        '#multiple' => FALSE,
        '#description' => t('Select if the language access header is to be automatically inserted into the page.'),
    );
    }

    /**
     * NYS Universal Navigation language access field.
     *
     * @return array
     *   Form API element for field.
     */
    public function _nys_unav_language_access_footer() {
    $config = $this->config('nys_unav.settings');
    return array(
        '#type' => 'checkbox',
        '#title' => t('Enable the Language Access Footer'),
        '#default_value' => $config->get('nys_unav.nys_unav_language_access_footer'),
        '#multiple' => FALSE,
        '#description' => t('Select if the language access footer is to be automatically inserted into the page.'),
    );
    }


}